/*-
 * Copyright (c) 2000
 * Tatsuya Kudoh(CDR/TK),ROYALPANDA.    All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */
#include<stdlib.h>
#include<stdio.h>
#include<sys/bios.h>

#include"soari.h"

int title( int mode, unsigned score, unsigned hiscore, int level )
{
	static char buf[32];
	unsigned key,prev;

	draw_title();
	fade_in();

	sprintf(buf,"HI%5u00  SC%5u00  LV%2d",hiscore,score,level);
	draw_letter(buf,1,1);

	draw_letter("START",8,13);
	draw_letter("CONTINUE",8,14);
	draw_letter("EXIT",8,15);

	sprintf(buf,"VER %s",VERSION);
	draw_letter(buf,20,12);

	draw_letter("(C) 2000 ROYALPANDA",4,17);

	draw_letter(">",6,mode+13);

	prev = 0;

	for(;;){
		wait_v();
		key = key_press_check();
		if( key == prev )
			continue;
		prev = key;

		draw_letter(" ",6,mode+13);
		if( key & (KEY_A|KEY_START) )
			break;
		key &= (KEY_UP1|KEY_DOWN1);
		if( key == KEY_UP1 ){
			if( mode > 0 )
				mode--;
		}else if( key == KEY_DOWN1 ){
			if( mode < 2 )
				mode++;
		}
		draw_letter(">",6,mode+13);
	}

	return mode;
}
